(this.webpackJsonpstreamlit_datalist=this.webpackJsonpstreamlit_datalist||[]).push([[0],{17:function(e,t,a){e.exports=a(24)},24:function(e,t,a){"use strict";a.r(t);var l=a(6),n=a.n(l),o=a(15),r=a.n(o),i=a(5),s=a(0),u=a(1),d=a(2),c=a(3),p=a(7),m=function(e){Object(d.a)(a,e);var t=Object(c.a)(a);function a(){var e;Object(s.a)(this,a);for(var l=arguments.length,o=new Array(l),r=0;r<l;r++)o[r]=arguments[r];return(e=t.call.apply(t,[this].concat(o))).state={selection:null,isFocused:!1,value:""},e.render=function(){var t,a=e.props.args,l=a.options,o=a.label,r=a.def_val,s=a.widget_disabled,u=0,d=[],c=Object(i.a)(l);try{for(c.s();!(t=c.n()).done;){var p=t.value;d.push(n.a.createElement("option",{value:p,id:p,key:u})),u+=1}}catch(g){c.e(g)}finally{c.f()}var m=e.props.theme,v={},f={};return v.width="100%",v.fontSize="14px",v.lineHeight="1.6",v.transform="scale(1,0.95)",v.fontFamily=null===m||void 0===m?void 0:m.font,v.marginBottom="0.5rem",v.height="auto",v.minHeight="1.5rem",v.verticalAlign="middle",f.width="100%",f.backgroundColor=null===m||void 0===m?void 0:m.secondaryBackgroundColor,f.color=null===m||void 0===m?void 0:m.textColor,f.padding="8px",f.lineHeight="1.4",f.borderRadius="0.25rem",f.fontSize="16px",f.border="1px solid",f.borderColor="rgb(0,0,0,0)",f.textIndent="2px",f.fontWeight="normal",e.state.isFocused&&(f.borderColor=null===m||void 0===m?void 0:m.primaryColor,f.outline="0px"),!0===s&&(f.color="rgba(120,120,120,0.65)",v.color="rgba(120,120,120,0.65)"),n.a.createElement("span",null,n.a.createElement("label",{style:v}," ",o," ",n.a.createElement("br",null)," "),n.a.createElement("input",{style:f,list:"datalist-datalist",name:"datalist",id:"datalist",defaultValue:r,onKeyDown:e._handleKeyPress,onFocus:e._onFocus,onBlur:e._onBlur,key:r,disabled:s,autoComplete:"off"}),n.a.createElement("datalist",{id:"datalist-datalist",className:"rowWid"},d))},e._handleKeyPress=function(e){"Enter"===e.key&&(""===e.target.value?p.a.setComponentValue([null]):p.a.setComponentValue([e.target.value]))},e._onFocus=function(){e.setState({isFocused:!0})},e._onBlur=function(t){e.setState({isFocused:!1}),""===t.target.value?p.a.setComponentValue([null]):p.a.setComponentValue([t.target.value])},e}return Object(u.a)(a,[{key:"_updateInputValue",value:function(e){""===e.target.value?p.a.setComponentValue([null]):p.a.setComponentValue([e.target.value])}}]),a}(p.b),v=Object(p.c)(m);r.a.render(n.a.createElement(n.a.StrictMode,null,n.a.createElement(v,null)),document.getElementById("root"))}},[[17,1,2]]]);
//# sourceMappingURL=main.f77b83ac.chunk.js.map